@@ -462,6 +462,12 @@ class InferenceControllerOnPremConfig(BaseModel):
     )
 
 
+class LLMLoraConfig(BaseModel):
+    name: str
+    hf_repo: str
+    hf_token: Optional[str]
+
+
 class InferenceDeploymentIn(BaseModel):
     name: str
     model: str
@@ -483,6 +489,8 @@ class InferenceDeploymentIn(BaseModel):
     controller_cloud_config: Optional[InferenceControllerCloudConfig] = None
     controller_on_prem_config: Optional[InferenceControllerOnPremConfig] = None
 
+    llm_loras: Optional[LLMLoraConfig] = None
+
     def __init__(self, **data: Any):
         # Validate that controller_cloud_config or controller_on_prem_config is provided
         if not data.get("controller_cloud_config", None) and not data.get(
@@ -616,6 +624,7 @@ class AutotrainParams(BaseModel):
     batch_size: int = Field(1, title="Batch size for training")
     epochs: int = Field(1, title="Number of training epochs")
     train_subset: Optional[str] = None
+    valid_split: Optional[str] = None
     text_column: Optional[str] = None
     gradient_accumulation: Optional[int] = None
     max_model_length: Optional[int] = Field(
